@@ -31,6 +31,8 @@ my ( $opt, $usage ) = describe_options(
   [ 'verbose|v', "print extra stuff" ],
   [ 'db_only'     => 'create only the database, do not run any blast cmd' ],
   [ 'db_prefix=s' => 'set this as db_prefix for the blast db name' ],
+  [ 'db_hashidx'     => 'pass hash_index cmd to makeblastdb' ],
+  [ 'db_parseids'     => 'pass parse_seqids to makeblastdb' ],
   [
     "type" => hidden => {
       one_of => [
@@ -73,7 +75,8 @@ if ( $opt->use_db ) {
     seq_file   => $sfile,
     alphabet   => $blast_type{ $opt->type }[ALPHABET],
     wd         => $dir,
-    hash_index => 0
+    hash_index => $opt->db_hashidx,
+    parse_seqids => $opt->db_parseids,
   };
   $opts->{db_prefix} = $opt->db_prefix if ( $opt->db_prefix );
   $db_location = makeblastdb($opts);
