@@ -21,9 +21,11 @@ has _current_seq_id                 => ( is => 'rw' );
 has _current_strand                 => ( is => 'rw' );
 has _current_num                    => ( is => 'rw', default => 0 );
 has query_reverse_match_orientation => ( is => 'rw', default => 1 );
-has seq_id => (is => 'rw', default => 'ref01');
+has seq_id                          => ( is => 'rw', default => 'ref01' );
+has format                          => ( is => 'rw', default => 3 );
+has invert => (is => 'rw');
 
-our $VERSION = '0.0549'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 sub BUILD {
   my ($self) = @_;
@@ -55,6 +57,7 @@ sub next_feat {
   my $cur_id     = $self->_current_seq_id;
   my $cur_strand = $self->_current_strand;
   while ( defined( $l = $fhi->() ) ) {
+    my ( $seq_id, $rstart, $qstart, $len );
     if ( $l =~ /^>\s*(.*)/ ) {
       $cur_id = $1;
       if ( $cur_id =~ s/\s+Reverse//i ) {
@@ -66,23 +69,54 @@ sub next_feat {
       $self->_current_seq_id($cur_id);
       $self->_current_strand($cur_strand);
       next;
-    } elsif ( $l =~ /^\s*(\d.*)/ ) {
-      my ( $rstart, $qstart, $len ) = split /\s+/, $1;
+    } elsif ( $l =~ /^\s+/ ) {
+      if ( $self->format eq '3' ) {
+        # 3 col format
+        ( undef, $rstart, $qstart, $len, my $rest ) = split /\s+/, $l;
+        if($rest) {
+          confess "it seems that you have 4 column output format";
+        }
+        $seq_id = $self->seq_id;
+      } else {
+        # 4 col format
+        ( undef, $seq_id, $rstart, $qstart, $len ) = split /\s+/, $l;
+        if(not defined($len)) {
+          confess "it seems that you have 3 column output format";
+        }
+      }
+      if($self->invert) {
       return Bio::Gonzales::Feat->new(
-        seq_id     => $self->seq_id,
+        seq_id     => $cur_id, 
+        source     => 'mummer',
+        type       => 'match',
+        start      => $qstart,
+        end        => $qstart + $len,
+        strand     => $cur_strand,
+        attributes => {
+          ID     => [ $self->_next_id ],
+          Target => [ join( " ", $seq_id, $rstart, $rstart + $len, '+') ],
+          Query_reverse_match_orientation => [ $self->query_reverse_match_orientation ],
+          Ontology_term                   => ['SO:0000343'],
+          Match_len                       => [$len],
+        },
+      );
+      } else {
+      return Bio::Gonzales::Feat->new(
+        seq_id     => $seq_id,
         source     => 'mummer',
         type       => 'match',
         start      => $rstart,
         end        => $rstart + $len,
         strand     => 1,
         attributes => {
-          ID                              => [ $self->_next_id ],
-          Target                          => [ join( " ", $cur_id, $qstart, $qstart + $len, strand_convert($cur_strand) ) ],
+          ID     => [ $self->_next_id ],
+          Target => [ join( " ", $cur_id, $qstart, $qstart + $len, strand_convert($cur_strand) ) ],
           Query_reverse_match_orientation => [ $self->query_reverse_match_orientation ],
           Ontology_term                   => ['SO:0000343'],
-          Match_len => [ $len ],
+          Match_len                       => [$len],
         },
       );
+    }
     } else {
       last;
     }
