@@ -6,20 +6,20 @@ use Carp;
 use Data::Dumper;
 use List::MoreUtils qw/uniq/;
 use Bio::Gonzales::Util qw/flatten/;
+use Text::CSV_XS qw/csv/;
 
 use Bio::Gonzales::Matrix::Util qw/uniq_rows/;
 
-
 use 5.010;
 
 use List::Util qw/max/;
-use Bio::Gonzales::Util::File qw/open_on_demand slurpc/;
+use Bio::Gonzales::Util::File qw/open_on_demand slurpc expand_home/;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0549'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
-@EXPORT      = qw(mslurp mspew lslurp miterate lspew dict_slurp dict_spew);
+@EXPORT      = qw(mslurp mspew lslurp miterate lspew dict_slurp dict_spew xcsv_slurp);
 %EXPORT_TAGS = ();
 @EXPORT_OK   = qw(lspew xlsx_slurp xlsx_spew);
 my $COMMENT_RE = qr/^\s*#/;
@@ -39,7 +39,7 @@ sub dict_slurp {
     record_filter    => undef,
     commented_header => undef,
     concat_keys      => 1,
-    sort_keys      => 0,
+    sort_keys        => 0,
     %$cc
   );
 
@@ -76,7 +76,7 @@ sub dict_slurp {
       $raw_row =~ s/\r\n/\n/;
       chomp $raw_row;
       @header = split /$c{sep}/, $raw_row;
-      @header = ref $vidx ? @header[@$vidx]: ($header[$vidx]) if(defined $vidx && $vidx ne 'all');
+      @header = ref $vidx ? @header[@$vidx] : ( $header[$vidx] ) if ( defined $vidx && $vidx ne 'all' );
       last;
     }
   }
@@ -96,7 +96,7 @@ sub dict_slurp {
 
     for my $kidx (@kidcs) {
 
-      my @k = ( ref $kidx ?  @r[@$kidx] : $r[$kidx] );
+      my @k = ( ref $kidx ? @r[@$kidx] : $r[$kidx] );
       @k = map { $_ // '' } @k;
       @k = sort @k if ( $c{sort_keys} );
       my $k = join( $;, @k ) // '';
@@ -106,10 +106,10 @@ sub dict_slurp {
       } elsif ( not defined $vidx ) {
         $map{$k}++;
       } elsif ($uniq) {
-        $map{$k} = ( ref $vidx ? [ @r[@$vidx] ] : ($vidx eq 'all' ? \@r : $r[$vidx] ));
+        $map{$k} = ( ref $vidx ? [ @r[@$vidx] ] : ( $vidx eq 'all' ? \@r : $r[$vidx] ) );
       } else {
         $map{$k} //= [];
-        push @{ $map{$k} }, ( ref $vidx ? [ @r[@$vidx] ] : ($vidx eq 'all' ? \@r : $r[$vidx] ));
+        push @{ $map{$k} }, ( ref $vidx ? [ @r[@$vidx] ] : ( $vidx eq 'all' ? \@r : $r[$vidx] ) );
       }
     }
   }
@@ -151,14 +151,14 @@ sub mslurp {
     comment          => $COMMENT_RE,
     commented_header => undef,
     record_filter    => undef,
-    col_idx => undef,
+    col_idx          => undef,
     %$cc
   );
 
   my $record_filter = $c{record_filter};
 
   my @col_idx;
-  @col_idx = @{$c{col_idx}} if($c{col_idx} && ref $c{col_idx} eq 'ARRAY');
+  @col_idx = @{ $c{col_idx} } if ( $c{col_idx} && ref $c{col_idx} eq 'ARRAY' );
   my @header;
   my @row_names;
 
@@ -193,7 +193,7 @@ sub mslurp {
 
     push @row_names, shift @row if ( $c{row_names} );
 
-    push @m, (@col_idx ? [ @row[@col_idx] ] : \@row);
+    push @m, ( @col_idx ? [ @row[@col_idx] ] : \@row );
   }
   $fh->close unless ($fh_was_open);
 
@@ -207,6 +207,31 @@ sub mslurp {
   }
 }
 
+sub xcsv_slurp {
+  my ( $src, $c ) = @_;
+
+  my ( $fh, $fh_was_open ) = open_on_demand( $src, '<' );
+
+  my $data = do { local $/; <$fh> }
+    or confess "No data to analyze\n";
+  $fh->close unless ($fh_was_open);
+
+  $c->{sep} //=
+      $data =~ m/["\d],["\d,]/ ? ","
+    : $data =~ m/["\d];["\d;]/ ? ";"
+    : $data =~ m/["\d]\t["\d]/ ? "\t"
+    :
+    # If neither, then for unquoted strings
+      $data =~ m/\w,[\w,]/ ? ","
+    : $data =~ m/\w;[\w;]/ ? ";"
+    : $data =~ m/\w\t[\w]/ ? "\t"
+    :                        ",";
+  open my $dfh, '<', \$data or die "Can't open filehandle: $!";
+  my $aoa = csv( in => $dfh, sep_char => $c->{sep}, quote_char => '"', escape_char => '"' );
+  close $dfh;
+  return $aoa;
+}
+
 sub miterate {
   my ( $src, $cc ) = @_;
   my ( $fh, $fh_was_open ) = open_on_demand( $src, '<' );
@@ -215,7 +240,7 @@ sub miterate {
   my %c = (
     sep           => qr/\t/,
     skip          => 0,
-    comment          => $COMMENT_RE,
+    comment       => $COMMENT_RE,
     record_filter => undef,
     %$cc
   );
@@ -245,10 +270,10 @@ sub miterate {
 sub lspew {
   my ( $dest, $l, $c ) = @_;
   my $delim = $c->{sep} // $c->{delim} // "\t";
-  my $header   = $c->{header}    // $c->{ids};
+  my $header = $c->{header} // $c->{ids};
   my ( $fh, $fh_was_open ) = open_on_demand( $dest, '>' );
 
-  say $fh join($delim, @$header) if($header && @$header > 0);
+  say $fh join( $delim, @$header ) if ( $header && @$header > 0 );
 
   if ( ref $l eq 'HASH' ) {
     while ( my ( $k, $v ) = each %$l ) {
@@ -324,7 +349,11 @@ sub mspew {
   my ( $fh, $fh_was_open ) = open_on_demand( $dest, '>' );
 
   #print header if we have header
-  say $fh join $sep, @{ _quote( $header, $quote_is_on, $na_value ) } if ($header);
+  if ($header) {
+    my @qhead = @{ _quote( $header, $quote_is_on, $na_value ) };
+    unshift @qhead, '' if ( $rownames && !$c->{r_style_header} );
+    say $fh join $sep, @qhead;
+  }
 
   #iterate through rows
   for ( my $i = 0; $i < $num_rows; $i++ ) {
@@ -334,7 +363,7 @@ sub mspew {
     #add the values
     push @r, @{ $m->[$i] // [] } if ( $i < @$m );
     #fill the square if desired
-    if ($square) {
+    if ( $square || $fill_rows ) {
       my $missing = $num_cols - @r;
       push @r, (undef) x $missing;
     }
@@ -349,8 +378,7 @@ sub _quote {
   my ( $f, $q, $na ) = @_;
   $na = "$na" if ( $q && defined $na );
   my @fields = map {
-    if ( !defined )
-    {
+    if ( !defined ) {
       $na;
     } elsif ( !$q || /^\d+$/ ) {
       $_;
@@ -378,7 +406,11 @@ sub xlsx_spew {
 
   my @table;
   #print header if we have header
-  push @table, $header if ($header);
+  if ($header) {
+    my @qhead = @$header;
+    unshift @qhead, '' if ($rownames);
+    push @table, \@qhead;
+  }
 
   #iterate through rows
   for ( my $i = 0; $i < @$m; $i++ ) {
@@ -397,6 +429,7 @@ sub xlsx_spew {
 
   my $workbook  = Excel::Writer::XLSX->new($fh);
   my $worksheet = $workbook->add_worksheet();
+  $worksheet->keep_leading_zeros() if($c->{keep_leading_zeros});
   $worksheet->write_col( 'A1', \@table );
   $workbook->close;
   $fh->close unless ($fh_was_open);
@@ -408,26 +441,32 @@ sub xlsx_slurp {
   #my @m;
   #my ( $fh, $fh_was_open ) = open_on_demand( $src, '<' );
 
-  eval "use Spreadsheet::XLSX; 1" or confess "could not load Spreadsheet::XLSX";
+  eval "use Spreadsheet::ParseXLSX; 1" or confess "could not load Spreadsheet::ParseXLSX";
 
-  my $excel = Spreadsheet::XLSX->new($src);
+  $src = expand_home($src) if ( !ref($src) );
 
-  my %ms;
-
-  for my $sheet ( @{ $excel->{Worksheet} } ) {
-
-    my $sname = $sheet->{Name};
-
-    my @m;
-    my $cells = $sheet->{Cells};
-    for my $r (@$cells) {
-      my @e;
-      for my $cell (@$r) { push @e, $cell->{Val}; }
-      push @m, \@e;
-    }
-    $ms{$sname} = \@m;
+  my $parser   = Spreadsheet::ParseXLSX->new;
+  my $workbook = $parser->parse($src);
+  if ( !defined $workbook ) {
+    confess $parser->error(), ".\n";
   }
-  return \%ms;
+
+  my @ws;
+  for my $worksheet ( $workbook->worksheets() ) {
+    my @w;
+    my ( $row_min, $row_max ) = $worksheet->row_range();
+    my ( $col_min, $col_max ) = $worksheet->col_range();
+    for ( my $i = $row_min; $i <= $row_max; $i++ ) {
+      my @r;
+      for ( my $j = $col_min; $j <= $col_max; $j++ ) {
+        my $e = $worksheet->get_cell( $i, $j );
+        push @r, (defined($e) ? $e->unformatted : undef);
+      }
+      push @w, \@r;
+    }
+    push @ws, \@w;
+  }
+  return \@ws;
 }
 
 1;
