@@ -23,7 +23,7 @@ use POSIX;
 
 use 5.010;
 
-our $VERSION = '0.0549'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 has '_config_key_cache' => ( is => 'rw', default => sub { {} } );
 has '_nfi_cache'        => ( is => 'rw', default => sub { {} } );
@@ -208,7 +208,7 @@ sub path_to {
   my $home = Bio::Gonzales::Util::Development::File::find_root(
     {
       location => '.',
-      dirs     => [ '.git', 'analysis', 'doc', ],
+      dirs     => [ '.git', 'analysis', ],
       files    => ['Makefile']
     }
   );
