@@ -5,9 +5,12 @@ use Mouse;
 use overload '""' => 'all';
 use Carp;
 use Data::Dumper;
-use Bio::Gonzales::Seq::IO;
+use Digest::SHA1 qw/sha1_hex/;
+use Digest::MD5 qw/md5_hex/;
 
-our $VERSION = '0.0549'; # VERSION
+
+our $WIDTH = 80;
+our $VERSION = '0.058'; # VERSION
 
 has id     => ( is => 'rw', required   => 1 );
 has desc   => ( is => 'rw', default    => '' );
@@ -22,6 +25,8 @@ sub _build_gaps {
   return $gaps;
 }
 
+sub ungapped_seq { return shift->gapless_seq(@_); }
+
 sub _build_length {
   return CORE::length( shift->seq() );
 }
@@ -48,6 +53,23 @@ sub BUILDARGS {
   return \%a;
 }
 
+sub as_hash {
+  my $self = shift;
+  return { id => $self->id, desc => $self->desc, seq => $self->seq, info => $self->info };
+}
+
+sub Format_seq_string {
+  my ($str, $width) = @_;
+  $width //= $WIDTH;
+
+  if ( defined $str && length($str) > 0 ) {
+    $str =~ tr/ \t\n\r//d;            # Remove whitespace and numbers
+    $str =~ s/\d+//g;
+    $str =~ s/(.{1,$width})/$1\n/g;
+    return $str;
+  }
+}
+
 sub def {
   my ($self) = @_;
 
@@ -83,10 +105,7 @@ around 'seq' => sub {
 };
 
 sub gapless_seq {
-  my ($self) = @_;
-
-  my $seq = $self->seq;
-  $seq =~ tr/-.//d;
+  (my $seq = shift->seq) =~ tr/-.//d;
   return $seq;
 }
 
@@ -100,14 +119,14 @@ sub rm_gaps {
 sub clone {
   my ($self) = @_;
 
-  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => $self->seq, delim => $self->delim );
+  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => $self->seq, delim => $self->delim, info => $self->info );
   #shift->clone_object(@_)
 }
 
 sub clone_empty {
   my ($self) = @_;
 
-  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => '', delim => $self->delim );
+  return __PACKAGE__->new( id => $self->id, desc => $self->desc, seq => '', delim => $self->delim , info => $self->info);
 }
 
 sub display_id { shift->id(@_) }
@@ -131,13 +150,14 @@ sub all { shift->stringify(@_) }
 sub all_formatted { shift->stringify_pretty(@_) }
 
 sub stringify_pretty {
-  my ($self) = @_;
+  my ($self, $width) = @_;
+  $width //= $WIDTH;
 
   return
       ">"
     . $self->id
     . ( $self->desc ? $self->delim . $self->desc : "" ) . "\n"
-    . Bio::Gonzales::Seq::IO::format_seq_string( $self->seq );
+    . Format_seq_string( $self->seq );
 }
 
 sub all_pretty { shift->stringify_pretty(@_) }
@@ -198,6 +218,11 @@ sub revcom {
   return $self;
 }
 
+sub revcom_seq {
+  my $self = shift;
+  return _revcom_from_string( $self->seq, $self->guess_alphabet );
+}
+
 sub subseq {
   my ( $self, $range, $c ) = @_;
 
@@ -227,6 +252,14 @@ sub subseq {
   return $new_seq;
 }
 
+sub sha1_checksum {
+  return sha1_hex(uc(shift->seq));
+}
+
+sub md5_checksum {
+  return md5_hex(uc(shift->seq));
+}
+
 sub subseq_as_string {
   my ( $self, $range, $c ) = @_;
 
@@ -278,7 +311,7 @@ sub subseq_as_string {
         if ( $seq =~ /[^AGCTN]/i );
     }
 
-    $seq = _revcom_from_string( $seq, $self->_guess_alphabet );
+    $seq = _revcom_from_string( $seq, $self->guess_alphabet );
   }
 
   return wantarray ? ( $seq, [ $b, $e, $strand, @rest ] ) : $seq;
