@@ -8,7 +8,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.0549'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 #no use yet
 our %alphabets = (
@@ -153,7 +153,7 @@ sub validate {
       }
       undef $header;
     } else {
-      $self->_add_error( $., " ERROR IM SCRPT " );
+      $self->_add_error( $., " ERROR IN THE SCRIPT" );
     }
   }
   return $self->_error_cache;
